@@ -15,9 +15,7 @@ corresponding formatter, either L<Text::Textile>, or L<Text::MultiMarkdown>.
 
 =head1 METHODS
 
-=over 4
-
-=item format_content_order
+=head2 format_content_order
 
 Format order can be 1-99. The main formatter runs on 15.
 
@@ -25,11 +23,11 @@ Format order can be 1-99. The main formatter runs on 15.
 
 sub format_content_order { 15 }
 
-=item format_content
+=head2 format_content
 
 Calls the formatter. Takes a ref to the content as well as the context object.
 The latter is needed in order to determine the main formatter via a call to
-
+C<< $c->pref('main_formatter') >>.
 
 =cut
 
@@ -46,8 +44,6 @@ sub format_content {
     }
 }
 
-=back 
-
 =head1 SEE ALSO
 
 L<MojoMojo>, L<Module::Pluggable::Ordered>, L<Text::Textile>
@@ -56,9 +52,10 @@ L<MojoMojo>, L<Module::Pluggable::Ordered>, L<Text::Textile>
 
 Marcus Ramberg <mramberg@cpan.org>
 
-=head1 License
+=head1 LICENSE
 
-This module is licensed under the same terms as Perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
